<?php

namespace Modules\QuestionSite\Http\Controller;

use App\Traits\Helper;
use App\Traits\Pipeline;
use Illuminate\Routing\Controller;
use Modules\QuestionSite\Filter\Content;
use Modules\QuestionSite\Filter\DateFrom;
use Modules\QuestionSite\Filter\DateTo;
use Modules\QuestionSite\Filter\Title;
use Modules\QuestionSite\Filter\Type;
use Modules\QuestionSite\Http\Requests\CreateFaqRequest;
use Modules\QuestionSite\Http\Requests\UpdateFaqRequest;
use Modules\QuestionSite\Http\Resources\CreateFaqResource;
use Modules\QuestionSite\Http\Resources\DestroyFaqsResource;
use Modules\QuestionSite\Http\Resources\IndexFaqsResource;
use Modules\QuestionSite\Http\Resources\UpdateFaqsResource;
use Modules\QuestionSite\Models\Faq;
use Modules\QuestionSite\Repository\EloquentQuestionRepository;
use function App\Helper\onFaile;
use function App\Helper\onSuccess;

class QuestionController extends Controller
{
    use Pipeline,Helper;
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {

        $faqs=$this->pipelineWithoutPaginate(Faq::query()->select('id','title','content'),[Title::class,DateTo::class,DateFrom::class,Content::class]);

        return($faqs)?onSuccess($faqs):onSuccess([]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(CreateFaqRequest $request)
    {
//        return $request;
        $requests=  $request->validated();
        $faq=Faq::create($requests);
//            ['title'=>$requests->title,'content'=>$requests->content,]);
        return ($faq)?onSuccess($faq):onFaile('عملیات انجام نشد ');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateFaqRequest $request, $id)
    {

        $faqs=Faq::find($id);
//        return $faqs;
//        return            $faqs->update($request->validated());

        if($faqs){
            $faqs->update($request->validated());
            return onSuccess(Faq::find($id));
        }
        return onFaile('سوال مورد نظر یافت نشد');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $product = Faq::find($id);
        if($product)
            $product->delete();
        return ($product)?onSuccess([]):
            onFaile('سوال مورد نظر یافت نشد');
    }
}
